@@ -264,7 +264,7 @@ class NodeGraph ( Node ) :
             from graphtastic.clustering import connectivity as connections
             results = connections ( distm , alpha )
             L = [set() for i in range(len(results[0]))]
-            for c in results[1]:
+            for c in results['clustercontacts'] :
                 L[c[0]] = L[c[0]]|set([c[1]])
             return ( L )
         #
@@ -298,10 +298,18 @@ class NodeGraph ( Node ) :
         if not bNonRedundant :
             logic = lambda p,c : len(p&c) >= hierarchy_connections
         #
+        nm = np.shape(distm)
+        if not len ( nm ) == 2 :
+            print ( "DISTANCE MATRIX MUST BE A SQUAREFORM MATRIX" )
+            exit(1)
+        if not nm[0] == nm[1]:
+            print ( "DISTANCE MATRIX MUST BE A SQUAREFORM MATRIX" )
+            exit(1)
         R = sorted( list(set( distm.reshape(-1) ) ) )
         prev_clusters = []
         PClist = []
         for r in R :
+            # NOTE: THE LOCAL ROUTINE
             present_clusters = self.connectivity ( distm , r , cluster_connections )
             parent_child  = [ (p,c,r) for c in prev_clusters for p in present_clusters \
                           if logic(p,c)  ]
@@ -309,12 +317,16 @@ class NodeGraph ( Node ) :
             PClist = [ *PClist, *parent_child ]
         return ( PClist )
 
-    def distance_matrix_to_absolute_coordinates ( self , D:np.array , bSquared:bool = False, n_dimensions:int=2 ) -> np.array :
+    def distance_matrix_to_absolute_coordinates ( self , D:np.array , bSquared:bool = False, n_dimensions:int=2 , bLocal:bool=True ) -> np.array :
         #
         # SAME AS IN THE IMPETUOUS cluster.py EXCEPT THE RETURN IS TRANSPOSED
         # AND distg.m IN THE RICHTOOLS REPO
         # C++ VERSION HERE https://github.com/richardtjornhammar/RichTools/commit/be0c4dfa8f61915b0701561e39ca906a9a2e0bae
         #
+        if not bLocal : # JITTED VERSION
+            from graphtastic.fit import distance_matrix_to_absolute_coordinates as distm2coords
+            return ( distm2coords ( D , bSquared = bSquared, n_dimensions=n_dimensions ) )
+
         if not bSquared :
             D = D**2.
         DIM = n_dimensions
@@ -532,50 +544,7 @@ def value_equalisation( X:np.array , method:str='average' ) -> np.array :
     X_ = (rankdata( X , method=method )-0.5)/len(set(X))
     return ( X_ )
 
-def read_conversions(file_name) :
-    gene2ens = {} ; non_unique = []
-    with open( file_name , 'r' ) as infile:
-        if sys.version_info[0] < 3:
-            infile.next()
-        else :
-            next(infile)
-        for line in infile:
-            words = line.strip().split('\t')
-            if len(words)==2 :
-                ens, gene = words
-                if gene in gene2ens:
-                    gene2ens[gene].append(ens)
-                else :
-                    gene2ens[gene] = [ens]
-    return gene2ens
 
 
-def create_synonyms( convert_file , unique_mapping=False ):
-    # CREATE SYNONYMS
-    ens2sym , sym2ens = {} , {}
-    if unique_mapping:
-        sym2ens = read_gene_ensemble_conversion( convert_file )
-        ens2sym = { v:k for k,v in sym2ens.items() }
-    else :
-        sym2ens_list = read_conversions( convert_file )
-        ens2sym_list = {}
-        for s,L in sym2ens_list.items() :
-            for e in L:
-                if e in ens2sym_list:
-                    ens2sym_list.append(s)
-                else:
-                    ens2sym_list[e] = [s]
-        ens2sym = ens2sym_list
-        sym2ens = sym2ens_list
-    return ( ens2sym , sym2ens )
-
-
-def read_xyz(fname='argon.xyz',sep=' ') :
-    coords = []
-    with open(fname,'r') as input:
-        for line in input:
-            lsp = [u for u in line.replace('\n','').split(sep) if len(u)>0 ]
-            print(lsp,len(lsp))
-            if len(lsp) == 4:
-                coords.append( ( lsp[0],[ float(c) for c in lsp[1:]] ) )
-    return ( coords )
+if __name__ == '__main__' :
+    contributions__ = { "Richard Tjörnhammar": "All methods" }
